FluentUIContextMenuBuilder class

Inheritance
  • Object
  • AdaptiveComponentBuilder<AdaptiveContextMenu, Widget>
  • AdaptiveWidgetBuilder<AdaptiveContextMenu>
  • FluentUIContextMenuBuilder

Properties

componentName String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
name String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context, AdaptiveContextMenu component) Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toolbar(BuildContext context, Offset anchor, List<Widget> children) Widget
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited