FluentUIIconBuilder class

Inheritance
  • Object
  • AdaptiveComponentBuilder<AdaptiveIcon, Icon>
  • AdaptiveIconBuilder
  • FluentUIIconBuilder

Constructors

FluentUIIconBuilder(String iconName, IconData iconData)

Properties

componentName String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
iconData IconData
finalinherited
iconName String
finalinherited
name String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context, AdaptiveIcon component) Icon
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited